@@ -2,11 +2,11 @@ from __future__ import absolute_import, unicode_literals
 
 import logging
 
-from dingtalk.client import SecretClient  # NOQA
+from dingtalk.client import SecretClient, AppKeyClient  # NOQA
 from dingtalk.client.isv import ISVClient  # NOQA
 from dingtalk.core.exceptions import DingTalkClientException, DingTalkException  # NOQA
 
-__version__ = '1.1.4'
+__version__ = '1.3.7'
 __author__ = '007gzs'
 
 # Set default logging handler to avoid "No handler found" warnings.
