@@ -2,15 +2,21 @@
 from __future__ import absolute_import, unicode_literals
 
 from dingtalk.client.api.attendance import Attendance  # NOQA
+from dingtalk.client.api.blackboard import BlackBoard  # NOQA
 from dingtalk.client.api.bpms import Bpms  # NOQA
+from dingtalk.client.api.calendar import Calendar  # NOQA
 from dingtalk.client.api.callback import Callback  # NOQA
 from dingtalk.client.api.chat import Chat  # NOQA
 from dingtalk.client.api.checkin import Checkin  # NOQA
 from dingtalk.client.api.cspace import Cspace  # NOQA
 from dingtalk.client.api.department import Department  # NOQA
 from dingtalk.client.api.ext import Ext  # NOQA
+from dingtalk.client.api.extcontact import ExtContact  # NOQA
 from dingtalk.client.api.employeerm import Employeerm  # NOQA
+from dingtalk.client.api.health import Health  # NOQA
 from dingtalk.client.api.message import Message  # NOQA
 from dingtalk.client.api.microapp import MicroApp  # NOQA
+from dingtalk.client.api.report import Report  # NOQA
 from dingtalk.client.api.role import Role  # NOQA
 from dingtalk.client.api.user import User  # NOQA
+from dingtalk.client.api.workrecord import WorkRecord  # NOQA
